==> llm-docs-0.1.5.tgz: package/docs/DEVELOPMENT_ENVIRONMENT.md <==
---
id: DEVELOPMENT_ENVIRONMENT
---
# LLM Platform Development Environment

This document outlines the development environment setup for LLM Platform components. These guidelines provide consistency across development environments.

## System Requirements

### Minimum Requirements

- **CPU**: 4+ cores
- **RAM**: 16GB+
- **Disk**: 50GB+ SSD
- **GPU**: NVIDIA GPU with 8GB+ VRAM (for model inference)
- **OS**: Ubuntu 20.04+, macOS 12+, or Windows 10/11 with WSL2

### Recommended Requirements

- **CPU**: 8+ cores
- **RAM**: 32GB+
- **Disk**: 100GB+ SSD
- **GPU**: NVIDIA GPU with 16GB+ VRAM (T4, V100, A100)
- **OS**: Ubuntu 22.04 or macOS 13+

## Prerequisites

### Required Software

1. **Node.js**: v18.x LTS
   ```bash
   # Using nvm
   curl -o- https://raw.githubusercontent.com/nvm-sh/nvm/v0.39.3/install.sh | bash
   nvm install 18
   nvm use 18
   ```

2. **Docker**: Latest stable version
   ```bash
   # Ubuntu
   curl -fsSL https://get.docker.com -o get-docker.sh
   sudo sh get-docker.sh
   sudo usermod -aG docker $USER
   
   # macOS
   brew install --cask docker
   ```

3. **Docker Compose**: Latest stable version
   ```bash
   # Included with Docker Desktop
   # For Linux:
   sudo curl -L "https://github.com/docker/compose/releases/download/v2.18.1/docker-compose-$(uname -s)-$(uname -m)" -o /usr/local/bin/docker-compose
   sudo chmod +x /usr/local/bin/docker-compose
   ```

4. **Git**: Latest version
   ```bash
   # Ubuntu
   sudo apt-get install git
   
   # macOS
   brew install git
   ```

5. **NVIDIA CUDA Toolkit**: 11.8+ (for GPU acceleration)
   ```bash
   # Ubuntu
   sudo apt-get install nvidia-cuda-toolkit
   
   # macOS (Use container-based approach)
   ```

6. **Python**: v3.10+
   ```bash
   # Ubuntu
   sudo apt-get install python3.10 python3.10-venv python3-pip
   
   # macOS
   brew install python@3.10
   ```

7. **DDEV**: Latest version (for Drupal development)
   ```bash
   # Ubuntu/macOS
   curl -LO https://raw.githubusercontent.com/ddev/ddev/master/scripts/install_ddev.sh
   bash install_ddev.sh
   ```

8. **Composer**: Latest version (for PHP development)
   ```bash
   # Ubuntu/macOS
   php -r "copy('https://getcomposer.org/installer', 'composer-setup.php');"
   php composer-setup.php --install-dir=/usr/local/bin --filename=composer
   php -r "unlink('composer-setup.php');"
   ```

### Development Tools

1. **Visual Studio Code**: Latest version with extensions:
   - ESLint
   - Prettier
   - Docker
   - Remote Containers
   - Python
   - PHP IntelliSense
   - TypeScript
   - Jest

2. **Postman** or **Insomnia**: API testing

3. **Prometheus** & **Grafana**: Monitoring (via Docker Compose)

4. **MkDocs**: Documentation development
   ```bash
   pip install mkdocs mkdocs-material
   ```

5. **nvm**: Node.js version management

## Component Setup

Each component requires specific setup. Follow these instructions for each component.

### Base Repository Setup

1. Clone the repository:
   ```bash
   git clone https://github.com/yourusername/LLM.git
   cd LLM
   ```

2. Set up Git identity:
   ```bash
   git config user.name "Your Name"
   git config user.email "your.email@example.com"
   ```

3. Set up Git hooks:
   ```bash
   # From repository root
   npm run setup:hooks
   ```

### BFLLM Setup

1. Navigate to bfllm:
   ```bash
   cd bfllm
   ```

2. Install dependencies:
   ```bash
   npm install
   ```

3. Set up environment:
   ```bash
   cp .env.example .env
   # Edit .env with your config
   ```

4. Build the project:
   ```bash
   npm run build
   ```

5. Start development server:
   ```bash
   npm run dev
   ```

### llm-mcp Setup

1. Navigate to llm-mcp:
   ```bash
   cd llm-mcp
   ```

2. Install dependencies:
   ```bash
   npm install
   ```

3. Set up environment:
   ```bash
   cp .env.example .env
   # Edit .env with your config
   ```

4. Start development server:
   ```bash
   npm run dev
   ```

### Native AI.js Setup

1. Navigate to native_aijs:
   ```bash
   cd native_aijs
   ```

2. Install dependencies:
   ```bash
   npm install
   ```

3. Build the project:
   ```bash
   npm run build
   ```

### Drupal Integration Setup

1. Navigate to llm_platform_recipe:
   ```bash
   cd llm_platform_recipe
   ```

2. Start DDEV:
   ```bash
   ddev start
   ```

3. Install Drupal:
   ```bash
   ddev composer install
   ddev drush site-install --account-name=admin --account-pass=admin
   ```

4. Apply the recipe:
   ```bash
   ddev drush recipe:apply llm_platform
   ```

## Component Integration

### BFLLM and llm-mcp Integration

1. Run the MCP setup script:
   ```bash
   cd bfllm
   node scripts/setup-mcp-integration.js
   ```

2. Start both services:
   ```bash
   # In terminal 1
   cd bfllm
   npm run dev
   
   # In terminal 2
   cd llm-mcp
   npm run dev
   ```

3. Verify integration:
   ```bash
   curl http://localhost:3002/health
   ```

### Native AI.js and BFLLM Integration

1. In the bfllm directory, ensure native_aijs is added as a dependency:
   ```bash
   npm install --save ../native_aijs
   ```

2. Import and use native_aijs types and interfaces in bfllm code.

### Drupal and BFLLM Integration

1. Configure Drupal to connect to BFLLM:
   ```bash
   ddev drush config:set llm_platform_recipe.providers bfllm_url http://localhost:3002
   ```

## Docker-based Development

For a consistent development environment, you can use Docker Compose:

1. From the repository root:
   ```bash
   docker-compose up -d
   ```

2. This will start all components:
   - BFAPI on port 3000
   - llm-mcp on port 3001
   - BFLLM on port 3002
   - BFRFP on port 3003
   - Drupal on port 8080

## GPU Configuration

For GPU-accelerated development:

1. Ensure NVIDIA drivers are installed:
   ```bash
   nvidia-smi
   ```

2. Configure Docker to use NVIDIA runtime:
   ```bash
   # Add to /etc/docker/daemon.json
   {
     "default-runtime": "nvidia",
     "runtimes": {
       "nvidia": {
         "path": "nvidia-container-runtime",
         "runtimeArgs": []
       }
     }
   }
   ```

3. Restart Docker:
   ```bash
   sudo systemctl restart docker
   ```

4. In bfllm/.env, set:
   ```
   ML_INFERENCE_GPU=true
   TENSORFLOW_GPU_MEMORY_GROWTH=true
   ```

## Testing

Each component has its own testing requirements:

### BFLLM Testing

```bash
cd bfllm
npm test
```

### llm-mcp Testing

```bash
cd llm-mcp
npm test
```

### Native AI.js Testing

```bash
cd native_aijs
npm test
```

### Drupal Module Testing

```bash
cd llm_platform_recipe
ddev phpunit
```

## Monitoring Setup

1. Start the monitoring stack:
   ```bash
   cd bfllm
   npm run monitoring:start
   ```

2. Access Grafana at http://localhost:3000 (admin/admin)

3. Import dashboards from:
   ```
   bfllm/monitoring/dashboards/
   ```

## Troubleshooting Common Issues

### Node.js Version Issues

If you encounter dependency errors, ensure you're using the correct Node.js version:
```bash
nvm use 18
```

### GPU Detection Issues

If TensorFlow.js is not detecting your GPU:
```bash
# Check if CUDA is available
nvidia-smi

# Ensure TensorFlow can see the GPU
node -e "const tf = require('@tensorflow/tfjs-node-gpu'); console.log(tf.getBackend());"
```

### Docker Permission Issues

If you encounter permission issues with Docker:
```bash
sudo usermod -aG docker $USER
newgrp docker
```

### Package Dependency Issues

If you encounter errors about missing packages:
```bash
rm -rf node_modules package-lock.json
npm install
```

## Development Workflow

1. **Create Feature Branch**:
   ```bash
   git checkout -b feature/your-feature-name
   ```

2. **Write Tests First**:
   ```bash
   # Create test file
   touch __tests__/your-feature.test.ts
   # Write tests before implementation
   ```

3. **Implement Feature**:
   ```bash
   # Create implementation file
   touch src/your-feature.ts
   # Implement the feature
   ```

4. **Run Tests**:
   ```bash
   npm test
   ```

5. **Format and Lint**:
   ```bash
   npm run format
   npm run lint
   ```

6. **Commit and Push**:
   ```bash
   git add .
   git commit -m "feat: Add your feature description"
   git push origin feature/your-feature-name
   ```

7. **Create Pull Request**:
   - Use the GitLab/GitHub UI to create a PR
   - Ensure CI pipeline passes
   - Request review from appropriate team members

## Conclusion

This development environment setup provides a consistent and efficient workflow for the LLM Platform components. By following these guidelines, you'll be able to develop, test, and integrate components effectively.

For component-specific details, refer to the README.md file in each component directory.

---

**Last Updated**: May 31, 2025  
**Status**: Approved  
**Author**: Platform Engineering Team

==> llm-docs-1.0.1.tgz: package/docs/DEVELOPMENT_ENVIRONMENT.md <==
---
id: DEVELOPMENT_ENVIRONMENT
---
# LLM Platform Development Environment

This document outlines the development environment setup for LLM Platform components. These guidelines provide consistency across development environments.

## System Requirements

### Minimum Requirements

- **CPU**: 4+ cores
- **RAM**: 16GB+
- **Disk**: 50GB+ SSD
- **GPU**: NVIDIA GPU with 8GB+ VRAM (for model inference)
- **OS**: Ubuntu 20.04+, macOS 12+, or Windows 10/11 with WSL2

### Recommended Requirements

- **CPU**: 8+ cores
- **RAM**: 32GB+
- **Disk**: 100GB+ SSD
- **GPU**: NVIDIA GPU with 16GB+ VRAM (T4, V100, A100)
- **OS**: Ubuntu 22.04 or macOS 13+

## Prerequisites

### Required Software

1. **Node.js**: v18.x LTS
   ```bash
   # Using nvm
   curl -o- https://raw.githubusercontent.com/nvm-sh/nvm/v0.39.3/install.sh | bash
   nvm install 18
   nvm use 18
   ```

2. **Docker**: Latest stable version
   ```bash
   # Ubuntu
   curl -fsSL https://get.docker.com -o get-docker.sh
   sudo sh get-docker.sh
   sudo usermod -aG docker $USER
   
   # macOS
   brew install --cask docker
   ```

3. **Docker Compose**: Latest stable version
   ```bash
   # Included with Docker Desktop
   # For Linux:
   sudo curl -L "https://github.com/docker/compose/releases/download/v2.18.1/docker-compose-$(uname -s)-$(uname -m)" -o /usr/local/bin/docker-compose
   sudo chmod +x /usr/local/bin/docker-compose
   ```

4. **Git**: Latest version
   ```bash
   # Ubuntu
   sudo apt-get install git
   
   # macOS
   brew install git
   ```

5. **NVIDIA CUDA Toolkit**: 11.8+ (for GPU acceleration)
   ```bash
   # Ubuntu
   sudo apt-get install nvidia-cuda-toolkit
   
   # macOS (Use container-based approach)
   ```

6. **Python**: v3.10+
   ```bash
   # Ubuntu
   sudo apt-get install python3.10 python3.10-venv python3-pip
   
   # macOS
   brew install python@3.10
   ```

7. **DDEV**: Latest version (for Drupal development)
   ```bash
   # Ubuntu/macOS
   curl -LO https://raw.githubusercontent.com/ddev/ddev/master/scripts/install_ddev.sh
   bash install_ddev.sh
   ```

8. **Composer**: Latest version (for PHP development)
   ```bash
   # Ubuntu/macOS
   php -r "copy('https://getcomposer.org/installer', 'composer-setup.php');"
   php composer-setup.php --install-dir=/usr/local/bin --filename=composer
   php -r "unlink('composer-setup.php');"
   ```

### Development Tools

1. **Visual Studio Code**: Latest version with extensions:
   - ESLint
   - Prettier
   - Docker
   - Remote Containers
   - Python
   - PHP IntelliSense
   - TypeScript
   - Jest

2. **Postman** or **Insomnia**: API testing

3. **Prometheus** & **Grafana**: Monitoring (via Docker Compose)

4. **MkDocs**: Documentation development
   ```bash
   pip install mkdocs mkdocs-material
   ```

5. **nvm**: Node.js version management

## Component Setup

Each component requires specific setup. Follow these instructions for each component.

### Base Repository Setup

1. Clone the repository:
   ```bash
   git clone https://github.com/yourusername/LLM.git
   cd LLM
   ```

2. Set up Git identity:
   ```bash
   git config user.name "Your Name"
   git config user.email "your.email@example.com"
   ```

3. Set up Git hooks:
   ```bash
   # From repository root
   npm run setup:hooks
   ```

### BFLLM Setup

1. Navigate to bfllm:
   ```bash
   cd bfllm
   ```

2. Install dependencies:
   ```bash
   npm install
   ```

3. Set up environment:
   ```bash
   cp .env.example .env
   # Edit .env with your config
   ```

4. Build the project:
   ```bash
   npm run build
   ```

5. Start development server:
   ```bash
   npm run dev
   ```

### BFMCP Setup

1. Navigate to bfmcp:
   ```bash
   cd bfmcp
   ```

2. Install dependencies:
   ```bash
   npm install
   ```

3. Set up environment:
   ```bash
   cp .env.example .env
   # Edit .env with your config
   ```

4. Start development server:
   ```bash
   npm run dev
   ```

### Native AI.js Setup

1. Navigate to native_aijs:
   ```bash
   cd native_aijs
   ```

2. Install dependencies:
   ```bash
   npm install
   ```

3. Build the project:
   ```bash
   npm run build
   ```

### Drupal Integration Setup

1. Navigate to llm_platform_recipe:
   ```bash
   cd llm_platform_recipe
   ```

2. Start DDEV:
   ```bash
   ddev start
   ```

3. Install Drupal:
   ```bash
   ddev composer install
   ddev drush site-install --account-name=admin --account-pass=admin
   ```

4. Apply the recipe:
   ```bash
   ddev drush recipe:apply llm_platform
   ```

## Component Integration

### BFLLM and BFMCP Integration

1. Run the MCP setup script:
   ```bash
   cd bfllm
   node scripts/setup-mcp-integration.js
   ```

2. Start both services:
   ```bash
   # In terminal 1
   cd bfllm
   npm run dev
   
   # In terminal 2
   cd bfmcp
   npm run dev
   ```

3. Verify integration:
   ```bash
   curl http://localhost:3002/health
   ```

### Native AI.js and BFLLM Integration

1. In the bfllm directory, ensure native_aijs is added as a dependency:
   ```bash
   npm install --save ../native_aijs
   ```

2. Import and use native_aijs types and interfaces in bfllm code.

### Drupal and BFLLM Integration

1. Configure Drupal to connect to BFLLM:
   ```bash
   ddev drush config:set llm_platform_recipe.providers bfllm_url http://localhost:3002
   ```

## Docker-based Development

For a consistent development environment, you can use Docker Compose:

1. From the repository root:
   ```bash
   docker-compose up -d
   ```

2. This will start all components:
   - BFAPI on port 3000
   - BFMCP on port 3001
   - BFLLM on port 3002
   - BFRFP on port 3003
   - Drupal on port 8080

## GPU Configuration

For GPU-accelerated development:

1. Ensure NVIDIA drivers are installed:
   ```bash
   nvidia-smi
   ```

2. Configure Docker to use NVIDIA runtime:
   ```bash
   # Add to /etc/docker/daemon.json
   {
     "default-runtime": "nvidia",
     "runtimes": {
       "nvidia": {
         "path": "nvidia-container-runtime",
         "runtimeArgs": []
       }
     }
   }
   ```

3. Restart Docker:
   ```bash
   sudo systemctl restart docker
   ```

4. In bfllm/.env, set:
   ```
   ML_INFERENCE_GPU=true
   TENSORFLOW_GPU_MEMORY_GROWTH=true
   ```

## Testing

Each component has its own testing requirements:

### BFLLM Testing

```bash
cd bfllm
npm test
```

### BFMCP Testing

```bash
cd bfmcp
npm test
```

### Native AI.js Testing

```bash
cd native_aijs
npm test
```

### Drupal Module Testing

```bash
cd llm_platform_recipe
ddev phpunit
```

## Monitoring Setup

1. Start the monitoring stack:
   ```bash
   cd bfllm
   npm run monitoring:start
   ```

2. Access Grafana at http://localhost:3000 (admin/admin)

3. Import dashboards from:
   ```
   bfllm/monitoring/dashboards/
   ```

## Troubleshooting Common Issues

### Node.js Version Issues

If you encounter dependency errors, ensure you're using the correct Node.js version:
```bash
nvm use 18
```

### GPU Detection Issues

If TensorFlow.js is not detecting your GPU:
```bash
# Check if CUDA is available
nvidia-smi

# Ensure TensorFlow can see the GPU
node -e "const tf = require('@tensorflow/tfjs-node-gpu'); console.log(tf.getBackend());"
```

### Docker Permission Issues

If you encounter permission issues with Docker:
```bash
sudo usermod -aG docker $USER
newgrp docker
```

### Package Dependency Issues

If you encounter errors about missing packages:
```bash
rm -rf node_modules package-lock.json
npm install
```

## Development Workflow

1. **Create Feature Branch**:
   ```bash
   git checkout -b feature/your-feature-name
   ```

2. **Write Tests First**:
   ```bash
   # Create test file
   touch __tests__/your-feature.test.ts
   # Write tests before implementation
   ```

3. **Implement Feature**:
   ```bash
   # Create implementation file
   touch src/your-feature.ts
   # Implement the feature
   ```

4. **Run Tests**:
   ```bash
   npm test
   ```

5. **Format and Lint**:
   ```bash
   npm run format
   npm run lint
   ```

6. **Commit and Push**:
   ```bash
   git add .
   git commit -m "feat: Add your feature description"
   git push origin feature/your-feature-name
   ```

7. **Create Pull Request**:
   - Use the GitLab/GitHub UI to create a PR
   - Ensure CI pipeline passes
   - Request review from appropriate team members

## Conclusion

This development environment setup provides a consistent and efficient workflow for the LLM Platform components. By following these guidelines, you'll be able to develop, test, and integrate components effectively.

For component-specific details, refer to the README.md file in each component directory.

---

**Last Updated**: May 31, 2025  
**Status**: Approved  
**Author**: Platform Engineering Team
